from setuptools import setup, find_packages

setup(
    name="boxcord",
    version="0.2.0",
    packages=find_packages(),
    install_requires=["requests"],
    entry_points={
        'console_scripts': [
            'boxcord = boxcord.cli:main',
        ],
    },
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
)


import requests
import json

class BoxCordClient:
    def __init__(self, token):
        self.token = token
        self.base_url = "https://discord.com/API/V10"
    def _request(self, method, endpoint, data=None):
        headers = {
            "Authorization": f"Bot {self.token}"
            "Content-Type": "application/json"
        }
        url = f"{self.base_url}{endpoint}"
        response = requests.request(method, url, headers=headers, json=data)
        if response.status_code // 100 != 2:
            print(f"Error: {response.status_code} - {response.text}")
        return response.json()
    def send_message(self, channel_id, content):
        data = {
            "content": content
        }
        endpoint = f"/channels/{channel_id}/messages"
        self._request("POST", endpoint, data)